import { geoInterruptedMollweideHemispheres, geoBertin1953, geoNaturalEarth1, geoPath, geoGraticule } from 'd3';

export const Marks = ({
  geoLines: { lines },
  worldAtlas: { countries, land, interiors },
  cities,
  sizeScale,
  sizeValue,
  spin,
}) => {
  const projection = geoNaturalEarth1().rotate([spin]);
  const path = geoPath(projection);
  const graticule = geoGraticule();

  return (
    <g className="marks">
      <path className="ocean" d={path({ type: 'Sphere' })} />
      {land.features.map((feature) => (
        <path className="land" d={path(feature)} fill="url(#dope)" />
      ))}
      <path className="graticules" d={path(graticule())} />
      {lines.features.map((feature) => (
        <path className="geo" d={path(feature)} />
      ))}
      <path className="interiors" d={path(interiors)} />
      {cities.map((d) => {
        const [x, y] = projection([d.lng, d.lat]);
        return (
          <circle
            className="cities"
            key={d.city}
            cx={x}
            cy={y}
            r={sizeScale(sizeValue(d))}
          />
        );
      })}
      {countries.features.map((feature) => (
        <path className="countries" d={path(feature)}>
          <title>{feature.properties.name}</title>
        </path>
      ))}
    </g>
  );
};
