import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { max, scaleSqrt } from 'd3';

import { Marks } from './Marks';
import { useWorldAtlas } from './useWorldAtlas';
import { useCities } from './useCities';
import { useGeoLines } from './useGeoLines';

const width = 960;
const height = 500;
let spin = 205;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const cities = useCities();
  const geoLines = useGeoLines();

  if (!worldAtlas || !cities || !geoLines) {
    return <pre>Loading...</pre>;
  }

  const sizeValue = d => d.population;
  const maxRadius = 15;
  const sizeScale = scaleSqrt()
  	.domain([0, max(cities, sizeValue)])
  	.range([0, maxRadius])
  
  return (
    <svg width={width} height={height} className="ok">
        
      <defs>
        <pattern id="dope" patternUnits="userSpaceOnUse" width="200" height="200">
        	<image
            href="https://64.media.tumblr.com/1852a2f3f90842a55b7028d3706ef502/tumblr_ml3unm4yni1rdov8ko1_400.gif"
            x="0" y="0" width="200" height="200"
          />
        </pattern>
      </defs>
      <g>
        <Marks
          geoLines={geoLines}
          worldAtlas={worldAtlas}
          cities={cities}
          sizeScale={sizeScale}
          sizeValue={sizeValue}
          spin={spin}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);